@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 """Aliases for the xonsh shell."""
 import os
+import re
 import sys
-import shlex
 import inspect
 import argparse
 import builtins
@@ -24,14 +24,26 @@ from xonsh.platform import (
 from xonsh.tools import unthreadable, print_color
 from xonsh.replay import replay_main
 from xonsh.timings import timeit_alias
-from xonsh.tools import argvquote, escape_windows_cmd_string, to_bool, swap_values
+from xonsh.tools import (
+    argvquote,
+    escape_windows_cmd_string,
+    to_bool,
+    swap_values,
+    strip_simple_quotes,
+)
 from xonsh.xontribs import xontribs_main
+from xonsh.ast import isexpression
 
 import xonsh.completers._aliases as xca
 import xonsh.history.main as xhm
 import xonsh.xoreutils.which as xxw
 
 
+@lazyobject
+def SUB_EXEC_ALIAS_RE():
+    return re.compile(r"@\(|\$\(|!\(|\$\[|!\[")
+
+
 class Aliases(cabc.MutableMapping):
     """Represents a location to hold and look up aliases."""
 
@@ -80,7 +92,7 @@ class Aliases(cabc.MutableMapping):
             else:
                 return value
         else:
-            expand_path = builtins.__xonsh_expand_path__
+            expand_path = builtins.__xonsh__.expand_path
             token, *rest = map(expand_path, value)
             if token in seen_tokens or token not in self._raw:
                 # ^ Making sure things like `egrep=egrep --color=auto` works,
@@ -115,7 +127,17 @@ class Aliases(cabc.MutableMapping):
 
     def __setitem__(self, key, val):
         if isinstance(val, str):
-            self._raw[key] = shlex.split(val)
+            f = "<exec-alias:" + key + ">"
+            if SUB_EXEC_ALIAS_RE.search(val) is not None:
+                # We have a sub-command, e.g. $(cmd), to evaluate
+                self._raw[key] = ExecAlias(val, filename=f)
+            elif isexpression(val):
+                # expansion substitution
+                lexer = builtins.__xonsh__.execer.parser.lexer
+                self._raw[key] = list(map(strip_simple_quotes, lexer.split(val)))
+            else:
+                # need to exec alias
+                self._raw[key] = ExecAlias(val, filename=f)
         else:
             self._raw[key] = val
 
@@ -150,19 +172,50 @@ class Aliases(cabc.MutableMapping):
                 p.pretty(dict(self))
 
 
+class ExecAlias:
+    """Provides a callable alias for xonsh source code."""
+
+    def __init__(self, src, filename="<exec-alias>"):
+        """
+        Parameters
+        ----------
+        src : str
+            Source code that will be
+        """
+        self.src = src if src.endswith("\n") else src + "\n"
+        self.filename = filename
+
+    def __call__(
+        self, args, stdin=None, stdout=None, stderr=None, spec=None, stack=None
+    ):
+        execer = builtins.__xonsh__.execer
+        frame = stack[0][0]  # execute as though we are at the call site
+        execer.exec(
+            self.src, glbs=frame.f_globals, locs=frame.f_locals, filename=self.filename
+        )
+
+    def __repr__(self):
+        return "ExecAlias({0!r}, filename={1!r})".format(self.src, self.filename)
+
+
+#
+# Actual aliases below
+#
+
+
 def xonsh_exit(args, stdin=None):
     """Sends signal to exit shell."""
     if not clean_jobs():
         # Do not exit if jobs not cleaned up
         return None, None
-    builtins.__xonsh_exit__ = True
+    builtins.__xonsh__.exit = True
     print()  # gimme a newline
     return None, None
 
 
 def xonsh_reset(args, stdin=None):
-    """ Clears __xonsh_ctx__"""
-    builtins.__xonsh_ctx__.clear()
+    """ Clears __xonsh__.ctx"""
+    builtins.__xonsh__.ctx.clear()
 
 
 @lazyobject
@@ -294,7 +347,7 @@ def _SOURCE_FOREIGN_PARSER():
 
 def source_foreign(args, stdin=None, stdout=None, stderr=None):
     """Sources a file written in a foreign shell language."""
-    env = builtins.__xonsh_env__
+    env = builtins.__xonsh__.env
     ns = _SOURCE_FOREIGN_PARSER.parse_args(args)
     ns.suppress_skip_message = (
         env.get("FOREIGN_ALIASES_SUPPRESS_SKIP_MESSAGE")
@@ -369,7 +422,7 @@ def source_alias(args, stdin=None):
     If sourced file isn't found in cwd, search for file along $PATH to source
     instead.
     """
-    env = builtins.__xonsh_env__
+    env = builtins.__xonsh__.env
     encoding = env.get("XONSH_ENCODING")
     errors = env.get("XONSH_ENCODING_ERRORS")
     for i, fname in enumerate(args):
@@ -396,7 +449,7 @@ def source_alias(args, stdin=None):
             src = fp.read()
         if not src.endswith("\n"):
             src += "\n"
-        ctx = builtins.__xonsh_ctx__
+        ctx = builtins.__xonsh__.ctx
         updates = {"__file__": fpath, "__name__": os.path.abspath(fpath)}
         with env.swap(**make_args_env(args[i + 1 :])), swap_values(ctx, updates):
             try:
@@ -430,7 +483,7 @@ def source_cmd(args, stdin=None):
     args.append("--envcmd=set")
     args.append("--seterrpostcmd=if errorlevel 1 exit 1")
     args.append("--use-tmpfile=1")
-    with builtins.__xonsh_env__.swap(PROMPT="$P$G"):
+    with builtins.__xonsh__.env.swap(PROMPT="$P$G"):
         return source_foreign(args, stdin=stdin)
 
 
@@ -461,7 +514,7 @@ def xexec(args, stdin=None):
     elif args[0] == "-h" or args[0] == "--help":
         return inspect.getdoc(xexec)
     else:
-        denv = builtins.__xonsh_env__.detype()
+        denv = builtins.__xonsh__.env.detype()
         try:
             os.execvpe(args[0], args, denv)
         except FileNotFoundError as e:
