@@ -91,7 +91,9 @@ def _collapsed_pwd():
     pwd = _replace_home_cwd().split(sep)
     l = len(pwd)
     leader = sep if l > 0 and len(pwd[0]) == 0 else ""
-    base = [i[0] if ix != l - 1 else i for ix, i in enumerate(pwd) if len(i) > 0]
+    base = [i[0]
+            if ix != l - 1 and i[0] != '.' else i[0:2]
+            if ix != l - 1 else i for ix, i in enumerate(pwd) if len(i) > 0]
     return leader + sep.join(base)
 
 
